=============================
Deployment and infrastructure
=============================

To serve a variety of users and use cases, these subprojects are being
developed to support notebook deployment in various contexts, including
multiuser capabilities and secure, scalable cloud deployments.

.. glossary::

    `jupyterhub <https://github.com/jupyterhub/jupyterhub>`__
        Multi-user notebook for organizations with pluggable authentication
        and scalability.
        `Documentation <https://jupyterhub.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyterhub/jupyterhub>`__

    `nbviewer <https://nbviewer.jupyter.org/>`__
        Share notebooks as static HTML on the web.
        `Documentation <https://github.com/jupyter/nbviewer>`__ |
        `Repo <https://github.com/jupyter/nbviewer>`__

    `Binder <https://mybinder.org/>`__
        Turn a Git repo into a collection of interactive notebooks
        `Documentation <https://mybinder.readthedocs.io/en/latest/index.html>`__ |
        `Repo <https://github.com/jupyterhub/binder>`__

    `dockerspawner <https://github.com/jupyterhub/dockerspawner>`__
        Deploy notebooks for 'jupyterhub' inside Docker containers.
        `Documentation <https://github.com/jupyterhub/dockerspawner>`__ |
        `Repo <https://github.com/jupyterhub/dockerspawner>`__

    `docker-stacks <https://github.com/jupyter/docker-stacks>`__
        Stacks of Jupyter applications and kernels as Docker containers.
        `Documentation <https://github.com/jupyter/docker-stacks>`__ |
        `Repo <https://github.com/jupyter/docker-stacks>`__
